@@ -95,6 +95,8 @@ def parse_date(datestring, default_timezone=UTC):
     tz = parse_timezone(groups["timezone"], default_timezone=UTC)
     if groups["fraction"] is None:
         groups["fraction"] = 0
+    else:
+        groups["fraction"] = int(float("0.%s" % groups["fraction"]) * 1e6)
     return datetime(int(groups["year"]), int(groups["month"]), int(groups["day"]),
         int(groups["hour"]), int(groups["minute"]), int(groups["second"]),
         int(groups["fraction"]), tz)
