@@ -27,7 +27,21 @@ def test_parse_date_fraction():
     assert d.hour == 15
     assert d.minute == 34
     assert d.second == 56
-    assert d.microsecond == 123
+    assert d.microsecond == 123000
+    assert d.tzinfo == iso8601.UTC
+
+def test_parse_date_fraction_2():
+    """From bug 6
+    
+    """
+    d = iso8601.parse_date("2007-5-7T11:43:55.328Z'")
+    assert d.year == 2007
+    assert d.month == 5
+    assert d.day == 7
+    assert d.hour == 11
+    assert d.minute == 43
+    assert d.second == 55
+    assert d.microsecond == 328000
     assert d.tzinfo == iso8601.UTC
 
 def test_parse_date_tz():
@@ -38,7 +52,7 @@ def test_parse_date_tz():
     assert d.hour == 15
     assert d.minute == 34
     assert d.second == 56
-    assert d.microsecond == 123
+    assert d.microsecond == 123000
     assert d.tzinfo.tzname(None) == "+02:30"
     offset = d.tzinfo.utcoffset(None)
     assert offset.days == 0
@@ -76,3 +90,17 @@ def test_parse_no_timezone():
     assert d.second == 0
     assert d.microsecond == 0
     assert d.tzinfo == iso8601.UTC
+
+def test_space_separator():
+    """Handle a separator other than T
+    
+    """
+    d = iso8601.parse_date("2007-06-23 06:40:34.00Z")
+    assert d.year == 2007
+    assert d.month == 6
+    assert d.day == 23
+    assert d.hour == 6
+    assert d.minute == 40
+    assert d.second == 34
+    assert d.microsecond == 0
+    assert d.tzinfo == iso8601.UTC
